@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoPrereqs;
 {
-  $Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.005';
+  $Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.006';
 }
 use Moose;
 with(
@@ -79,6 +79,8 @@ sub register_prereqs {
     my $files = $self->$method;
 
     foreach my $file (@$files) {
+      # skip binary files
+      next if $file->is_bytes;
       # parse only perl files
       next unless $file->name =~ /\.(?:pm|pl|t|psgi)$/i
                || $file->content =~ /^#!(?:.*)perl(?:$|\s)/;
@@ -146,7 +148,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 5.005
+version 5.006
 
 =head1 SYNOPSIS
 
